/**
 *  \file client/Chat.cpp
 *  \brief Implementation of the Chat class
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 16:09:10 +1200 (Thu, 19 Aug 2010) $
 *
 */

#include "Chat.h"

Chat::Chat(ChatID id, Outbox* outbox) {
  id_ = id;
  outbox_ = outbox;
}

void Chat::Receive(Message message) {
  mutex_.Lock();
  history_.push_back(message);
  mutex_.Unlock();
  Notify();
}

void Chat::Send(Message message) {
  mutex_.Lock();
  history_.push_back(message);
  outbox_->Send(message, id_);
  mutex_.Unlock();
  Notify();
}

void Chat::Leave(UserID user) {
  mutex_.Lock();
  outbox_->LeaveChat(user, id_);
  mutex_.Unlock();
}

void Chat::Invite(UserID sender, UserID target) {
  mutex_.Lock();
  outbox_->Invite(id_, sender, target);
  mutex_.Unlock();
}

Messages const Chat::history() {
  //ScopedLock(&mutex_);
  return history_;
}

UserID Chat::id() {
  //ScopedLock(&mutex_);
  return id_;
}