/*
 *  ChatManager.h
 *  chat
 *
 *  Created by John Hofman on 29/09/10.
 *  Copyright 2010 University of Canterbury. All rights reserved.
 *
 */

#ifndef CHATMANAGER_H
#define CHATMANAGER_H

#include "Chat.h"
#include "Subject.h"
#include "Mutex.h"
#include "Outbox.h"
#include "Factory.h"
#include "TypeDef.h"

class ChatManager: public Subject {
public:
  /**
   *  \brief Constructor 
   *  \param outbox The outbox to send outgoing messages to.
   */
  ChatManager(Factory* factory, Outbox* outbox);
  
  /**
   *  \brief Destructor
   */
  ~ChatManager(){}
  
  /**
   *  \brief Request a chat with another user.
   *  \param sender The user that initiated the request.
   *  \param target The target user of the request.
   */
  void RequestChat(UserID sender, UserID target);
  
  /**
   *  \brief Start a new chat.
   *  \param id The id of the new chat.
   */
  void NewChat(ChatID id);
  
  /**
   *  \brief End a chat.
   *  \param id The id of the chat to end.
   */
  void EndChat(ChatID id);
 
  /**
   *  \brief Make a chat receive a message.
   *  \param message The message to receive.
   */
  void Receive(ChatID id, Message message);
  
private:
  ChatMap chats_;
  Factory* factory_;
  Outbox* outbox_;
  Mutex mutex_;
};

#endif /* CHATMANAGER_H */