/**
 *  \file ClientSocket.h
 *  \brief Contains the definition of a client-side socket wrapper.
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 14:01:53 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef CLIENT_SOCKET_H
#define CLIENT_SOCKET_H

#include "TypeDef.h"
#include "Mutex.h"
#include "Socket.h"

/**
 *  \class ClientSocket
 *  \brief A client-side socket wrapper for communicating with the server.
 */
class ClientSocket : public Socket {
public:
  /**
   *  \brief Open a socket and connect to the given address.
   *  \param ip_addr the IP address or hostname to connect to.
   */
  ClientSocket(std::string ip_addr);
  
  virtual ~ClientSocket();
  
  /**
   *  \brief Send a packet to the socket.
   *  \param packet The packet to send;
   */
  virtual void Send(Packet* packet);
  
  /**
   *  \brief Receive a packet from the socket. This is a blocking function.
   *  \return The packet that has been recieved. NULL if no packet was received
   *  and the socket was disconnected.
   */
  virtual Packet* Receive();
  
private:
  //Sock identifier
  int sock;
  //Data separator for string serialisation and tokenising.
  static const char* dataSeparator;
};

#endif /* CLIENT_SOCKET_H */
