/**
 *  \file  Fl_Factory.h
 *  \brief The declaration of a FLTK factory for building GUI elements
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 14:38:13 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef FL_FACTORY_H
#define FL_FACTORY_H

#include "Factory.h"
#include "Chat.h"
#include "ChatManager.h"
#include "Fl_WindowedChat.h"
#include "UserList.h"
#include "LocalUser.h"
#include "Fl_WindowedUser.h"

// Forward declaration of Outbox
class Outbox;

/**
 *  \class Fl_Factory
 *  \brief An implementation of a Factory that builds chats and user managers
 *         using FLTK.
 */
class Fl_Factory : public Factory {
public:
  /**
   *  \brief Constructor
   *  \param outbox a pointer to an Outbox to pass to the constructors of Chat 
   *                and UserList
   */
  Fl_Factory(Outbox* outbox);
  
  /**
   *  /brief Destructor
   */
  virtual ~Fl_Factory(){}
  
  /**
   *  \brief Make a new chat
   *  \param chatid The id of the new chat
   *  \return the new chat
   */
  virtual Chat* GetNewChat(ChatID chatid);
  
  /**
   *  \brief Get the user manager
   *  \return the user manager.
   */
  virtual UserList* GetUserList();
  
  /**
   *  \brief Get the chat manager
   *  \return the chat manager
   */
  virtual ChatManager* GetChatManager();
  
  /**
   *  \brief Get the local user
   *  \return the local user
   */
  virtual LocalUser* GetLocalUser();
  
private:
  void Initialise();
  bool intialised;
  
  Outbox* outbox_;
  LocalUser* local_user_;
  ChatManager* chat_manager_;
  UserList* user_list_;
};
  
  

#endif /* FL_FACTORY_H */
