/**
 *  \file  Fl_WindowedChat.h
 *  \brief Declaration of the chat GUI
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 15:38:55 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef FL_WINDOWEDCHAT_H
#define FL_WINDOWEDCHAT_H

#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Return_Button.H>
#include <FL/Fl_Button.H>
#include <FL/Fl_Input.H>
#include <FL/Fl_Text_Display.H>
#include <FL/Fl_Text_Buffer.H>
#include <FL/fl_ask.h>

#include "Observer.h"
#include "Chat.h"
#include "ChatManager.h"
#include "LocalUser.h"

//Fltk Dimensions
#define C_WINDOW_W  320
#define C_WINDOW_H  300
#define C_INPUT_H   30
#define C_SEND_W    70
#define C_BORDER    15

/**
 *  \class Fl_WindowedChat
 *  \brief A GUI to a chat, implemented using FLTK
 */
class Fl_WindowedChat : public Fl_Double_Window, public Observer {
public:
  /**
   *  \brief Constructor
   *  \param chat a pointer to the chat to observe
   */
  Fl_WindowedChat(Chat* chat, LocalUser* local_user, ChatManager* chat_manager);
  
  /**
   *  \brief Destructor
   */
  virtual ~Fl_WindowedChat();
  
  /**
   *  \brief Implementation of the inherited operation Observer::Update. 
   */
  virtual void Update(Subject* subject);
  
  void End();
  
private:
  void Redraw();
  
  // Static callbacks for buttons
  static void cb_send(Fl_Widget* w, void* v);
  static void cb_invite(Fl_Widget* w, void* v);
  
  // Implementations for button callbacks
  void Send();
  void Invite();
  
  
  Chat* chat_;  ///< Observed Chat
  LocalUser* local_user_;
  ChatManager* chat_manager_;
  
  //Component Fl_Widgets
  Fl_Return_Button* send;
  Fl_Button* invite;
  Fl_Input* input;
  Fl_Text_Display* output;
  Fl_Text_Buffer* buffer;
};

#endif /* FL_WINDOWEDCHAT_H */
