/**
 *  \file  Fl_WindowedUser.h
 *  \brief Declaration of the UserList GUI
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 15:38:55 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef FL_WINDOWEDUSERLIST_H
#define FL_WINDOWEDUSERLIST_H

#include <FL/Fl.H>
#include <FL/Fl_Window.H>
#include <FL/Fl_Text_Display.H>
#include <FL/Fl_Input.H>
#include <FL/Fl_Return_Button.H>
#include <FL/fl_ask.h>

#include "Observer.h"
#include "UserList.h"
#include "ChatManager.h"
#include "LocalUser.h"

// Window dimensions
#define UM_WINDOW_W 300
#define UM_WINDOW_H 250
#define UM_BORDER_S 15
#define UM_BORDER_L 30
#define UM_LINE_H   30
#define UM_BUTTON_W 100

/**
 *  \class Fl_WindowedUser
 *  \brief A GUI to a UserList, implemented using FLTK
 */
class Fl_WindowedUser : public Fl_Window, public Observer {
public:
  /**
   *  \brief Constructor
   *  \param user_list a pointer to the UserList to observe
   */
  Fl_WindowedUser(UserList* user_list, LocalUser* local_user, ChatManager* chat_manager);
  
  /**
   *  \brief Destructor
   */
  virtual ~Fl_WindowedUser();
  
  /**
   *  \brief Implementation of the inherited operation Observer::Update. 
   */
  virtual void Update(Subject* subject);
  
  
private:
  void Redraw();
  
  //Static callbacks 
  static void window_cb(Fl_Widget* w, void* v);
  static void startchat_button_cb(Fl_Widget* w, void* v);  
  static void login_button_cb(Fl_Widget* w, void* v); 
  
  //Iplmentation of callbacks for buttons
  void StartChat();
  void Login();
  
  LocalUser* local_user_;
  UserList* user_list_;  ///< Observed UserList
  ChatManager* chat_manager_;

  //Component Fl_Widgets
  Fl_Return_Button *login_button;
  Fl_Return_Button *startchat_button;
  Fl_Input* username_input;
  Fl_Text_Display* users_list;
  Fl_Text_Buffer* users_buffer;
};

#endif /* FL_WINDOWEDUSERLIST_H */
