/**
 *  \file  client/Inbox.h
 *  \brief Implementation of the client-side Inobx class
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 16:09:10 +1200 (Thu, 19 Aug 2010) $
 *
 */

#include "Inbox.h"

Inbox::Inbox(Factory* factory, Socket* socket){
  socket_ = socket;
  local_user_ = factory->GetLocalUser();
  user_list_ = factory->GetUserList();
  chat_manager_ = factory->GetChatManager();
}

Inbox::~Inbox() {}

void Inbox::Run(){
  
  while(!waiting) {
    //Get a packet form the network
    Packet* packet = socket_->Receive();
    
    // Bail out if a packet couldn't be received
    if (packet == NULL) {
      local_user_->Disconnect();
      break;
    }
    
    //Process the packet appropriately
    switch (packet->command()) {
      case STARTCHAT:
        chat_manager_->NewChat(packet->chat());
        break;
      case SEND:
        chat_manager_->Receive(packet->chat(), packet->message());
        break;
      case ADDUSER:
        user_list_->Add(packet->target());
        break;
      case REMOVEUSER:
        user_list_->Remove(packet->target());
        break;
      case LOGINSUCCESS:
        local_user_->LoginSuccess(packet->target());
        break;
      case LOGINFAILED:
        local_user_->LoginFailed();
        break;
      default:
        break;
    }
    
    //Delete the packet
    delete packet;
  }
}
