/*
 *  LocalUser.cpp
 *  chat
 *
 *  Created by John Hofman on 29/09/10.
 *  Copyright 2010 University of Canterbury. All rights reserved.
 *
 */

#include "LocalUser.h"

LocalUser::LocalUser(Outbox* outbox) {
  outbox_ = outbox;
  id_ = "";
  state_ = LOGGED_OUT;
}

void LocalUser::LoginAttempt(UserID id) {
  mutex_.Lock();
  state_ = LOGGING_IN;
  outbox_->Login(id);
  mutex_.Unlock();
  Notify();
}

void LocalUser::LoginSuccess(UserID id) {
  mutex_.Lock();
  id_ = id;
  state_ = LOGGED_IN;
  mutex_.Unlock();
  Notify();
}

void LocalUser::LoginFailed() {
  mutex_.Lock();
  id_ = "";
  state_ = LOGGED_OUT;
  mutex_.Unlock();
  Notify();
}

void LocalUser::Logout() {
  mutex_.Lock();
  outbox_->Logout(id_);
  state_ = LOGGED_OUT;
  mutex_.Unlock();
}

void LocalUser::Disconnect() {
  mutex_.Lock();
  state_ = DISCONNECTED;
  mutex_.Unlock();
  Notify();
}

UserID LocalUser::id() {
  //ScopedLock(&mutex_);
  return id_;
}

LocalUser::State LocalUser::state() {
  //ScopedLock(&mutex_);
  return state_;
}