/**
 *  \file client/Outbox.h
 *  \brief Implements the Outbox class in the client.
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 16:09:10 +1200 (Thu, 19 Aug 2010) $
 *
 */

#include "Outbox.h"

Outbox::Outbox(Socket* socket) {
  socket_ = socket;
}

void Outbox::Login(UserID user) {
  //Make the login packet
  Packet* packet = new Packet(LOGIN);
  packet->sender(user);  
  socket_->Send(packet);
}

void Outbox::Logout(UserID user) {
  //Make the logout packet
  Packet* packet = new Packet(LOGOUT);
  packet->sender(user);  
  socket_->Send(packet);
}
  
void Outbox::StartChat(UserID sender, UserID target) {
  //Make the start chat packet
  Packet* packet = new Packet(STARTCHAT);
  packet->sender(sender);
  packet->target(target);
  socket_->Send(packet);  
}

void Outbox::Send(Message message, ChatID chat) {
  //Make the start chat packet
  Packet* packet = new Packet(SEND);
  packet->sender(message.user);
  packet->chat(chat);
  packet->message(message);
  socket_->Send(packet);    
}

void Outbox::Invite(ChatID chat, UserID sender, UserID target) {
  // Make the invite packet
  Packet* packet = new Packet(INVITE);
  packet->sender(sender);
  packet->chat(chat);
  packet->target(target);
  socket_->Send(packet);
}

void Outbox::LeaveChat(UserID user, ChatID id) {
  //Make the leave chat packet
  Packet* packet = new Packet(LEAVECHAT);
  packet->sender(user);
  packet->chat(id);
  socket_->Send(packet);  
}
