/**
 *  \file client/Outbox.h
 *  \brief Declares the Outbox class in the client.
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 16:09:10 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef OUTBOX_CLIENT_H
#define OUTBOX_CLIENT_H

#include "TypeDef.h"
#include "ClientSocket.h"


/**
 *  \class Outbox
 *  \brief Handles outbound communications from client to server
 */
class Outbox {
public:
  /**
   *  \brief Constructor
   *  \param socket a pointer to the socket to use for communications
   */
  Outbox(Socket* socket);
  
  /**
   *  \brief Destructor.
   */
  ~Outbox(){}
  
  /**
   *  \brief Login to the network.
   *  \param user The user id to login with.
   */
  void Login(UserID user);
  
  /**
   *  \brief Logout of the network.
   */
  void Logout(UserID user);
  
  /**
   *  \brief Start a chat with a user.
   *  \param user The user to start the chat with.
   */
  void StartChat(UserID sender, UserID target);
  
  /**
   *  \brief Leave a the chat.
   *  \param id The ID of the chat to leave.
   */
  void LeaveChat(UserID user, ChatID id);
  
  /**
   *  \brief Send a message to a chat.
   *  \param message The message to send.
   *  \param chat The chat to send the message to.
   */
  void Send(Message message, ChatID chat);
  
  /**
   *  \brief Invite a user to join a chat.
   *  \param chat The chat to invite them to.
   *  \param user The user to invite
   */
  void Invite(ChatID chat, UserID sender, UserID target);
  
private:
  Socket* socket_;
};

#endif /* OUTBOX_CLIENT_H */

