/**
 *  \file Socket.h
 *  \brief Declaration of a Socket class that handles sending and recieving
 *  Packets to a socket.
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 11:42:46 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef SOCKET_H
#define SOCKET_H

#include "Packet.h"

/**
 *  \class Socket
 *  \brief Handles reading and writing Packets to the socket.
 */
class Socket {
public:
  /**
   *  \brief Destructor.
   */
  virtual ~Socket(){};
  
  /**
   *  \brief Send a packet to the socket.
   *  \param packet The packet to send;
   */
  virtual void Send(Packet* packet) = 0;
  
  /**
   *  \brief Receive a packet from the socket. This is a blocking function.
   *  \return The packet that has been recieved. NULL if no packet was received
   *  and the socket was disconnected.
   */
  virtual Packet* Receive() = 0;
};

#endif // SOCKET_H
