/**
 *  \file Thread.cpp
 *  \brief Implementation of Thread class which encapsulates a posix thread. 
 *
 *  $LastChangedBy: jch231 $
 *  $Date: 2010-08-19 11:35:17 +1200 (Thu, 19 Aug 2010) $
 *
 */

#include "Thread.h"

/**
 *  \fn static void* ThreadStart(void* thread)
 *  \brief Static callback to start the thread. Needs to be an extern "C" 
 *  function because posix threads are implemented in C.
 *  \param thread A reference to the thread that was started.
 *  \return NULL when the thread has finished running.
 */
extern "C" {
  static void* ThreadStart(void* thread) {
    static_cast<Thread*>(thread)->Run();
    return 0;
  }
}

Thread::~Thread() {
  //Cancel the thread.
  pthread_cancel(thread_id);
}

void Thread::Start() {
  waiting = false;
  started = (pthread_create(&thread_id, NULL, &ThreadStart, this) == 0);
}

bool Thread::Wait() {
  waiting = true;
  return (!started || pthread_join(thread_id, NULL) == 0);
}
