/**
 *  \file TypeDef.h
 *  \brief Declaration of common typedefs.
 * 
 *  $LastChangedBy: jch231 $
 *  $Date: 2010-08-19 11:35:17 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef TYPEDEF_H
#define TYPEDEF_H

#include <list>
#include <string>
#include <set>
#include <map>

#define PORT "11235" // the port client will be connecting to 

/**
 *  \typedef UserID
 *  \brief ID for a User on the network.
 */
typedef std::string UserID;

/**
 *  \typedef Users
 *  \brief Collection of UserIDs
 */
typedef std::set<UserID> Users;

/**
 *  \typedef ChatID
 *  \brief ID for a chat on the network.
 */
typedef std::string ChatID;

/**
 *  \typedef ChatMap
 *  \brief A map for ChatID's to chats
 */
class Chat;
typedef std::map<ChatID,Chat*> ChatMap;

/**
 *  \struct Message
 *  \brief A structure that represents a message in a chat. The Message has a
 *  sending user and message text.
 */
struct Message {
  //Sending user
  UserID user;
  //Message contents
  std::string text;
  
  /**
   *  \brief Default Constructor
   */
  Message(){}
  
  /**
   *  \brief Constructor
   *  \param user_ The user who sent the messsage
   *  \param text_ The text contents of the message
   */
  Message(UserID user_, std::string text_){
    user = user_;
    text = text_;
  }
                                        
};

/**
 *  \brief Collection of messages.
 */
typedef std::list<Message> Messages;

#endif // TYPEDEF_H
