/**
 *  \file  client/UserManager.h
 *  \brief Declaration of a user manager
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 16:09:10 +1200 (Thu, 19 Aug 2010) $
 *  
 */

#ifndef USERLIST_H
#define USERLIST_H

#include "TypeDef.h"
#include "Subject.h"
#include "Mutex.h"
#include "Outbox.h"

/**
 *  \class UserList
 *  \brief Manages a set of UserIDs
 */
class UserList : public Subject {
public:
  
  /**
   *  \brief Constructor
   *  \param outbox a pointer to the outbox for outbound communications
   */
  UserList(Outbox* outbox);
  
  /**
   *  \brief Destructor
   */
  ~UserList(){}

  /**
   *  \brief Add a user.
   *  \param user The user to add.
   */
  void Add(UserID user);
  
  /**
   *  \brief Remove a user.
   *  \param user The user to remove.
   */
  void Remove(UserID user);
  
  /**
   *  \return The list of online users.
   */
  Users const users();
  
private:
  
  //Attributes
  Users users_;
  Outbox* outbox_;
  
  //Thread safety
  Mutex mutex_;
};

#endif /* USERLIST_H */

