/**
 *  \file client/main.cpp
 *  
 *  \brief This is the client for an instant messaging system. 
 */

#include <iostream>
#include <string>
#include "Fl_Factory.h"
#include "ClientSocket.h"
#include "UserList.h"
#include "Inbox.h"
#include "Outbox.h"

int main(int argc, char* argv[]) {
  // Read the IP address passed in on the command line (if any), otherwise
  // default to localhost.
  std::string server;
  if (argc < 2) {
    std::cerr << "No hostname given, so assuming 'localhost'." << std::endl;
    std::cerr << "To specify a different server, run `";
    std::cerr << argv[0] << " hostname_or_ip`" << std::endl;
    server = "localhost";
  } else {
    server = std::string(argv[1]);
  }
  
  // Initialise FLTK's locking mechanism
  Fl::lock();
  
  ClientSocket* socket  = new ClientSocket(server);
  Outbox*       outbox  = new Outbox(socket);
  Factory*      factory = new Fl_Factory(outbox);
  Inbox*        inbox   = new Inbox(factory, socket);
  
  // Start the Inbox thread
  inbox->Start();
  
  // Start the FLTK thread
  Fl::run();

  inbox->Wait();
  return 0;
}
