/**
 *  \file  server/Chat.h
 *  \brief Declaration of a server-side chat
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 16:42:25 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef CHAT_H
#define CHAT_H

#include <iostream>
#include "TypeDef.h"
#include "Mutex.h"
#include "Observable.h"
#include "Outbox.h"
#include "UserManager.h"

/**
 *  \class Chat
 *  \brief 
 */
class Chat : public Observable {
public:
  /**
   *  \brief Constructor
   *  \param id the ID of the chat
   *  \param user_sender the chat initiator
   *  \param user_target the user to chat to
   *  \param user_manager_ the UserManager to use
   */
  Chat(ChatID id, UserID user_sender, UserID user_target, 
       UserManager* user_manager_);
  
  /**
   * \brief Destructor
   */
  virtual ~Chat(){}
  
  /**
   * \brief Sends a message to the network connection.
   * \param message The message to be sent over the network connection.
   */
  void Receive(Message message);
  
  /**
   *  \brief Notify that a user has logged out
   *  \param user the user that logged out
   */
  void Logout(UserID user);
  
  /**
   *  \brief Remove a user from the chat
   *  \param user the user to remove
   */
  void Leave(UserID user);
  
  /**
   *  \brief Invite a user to the chat
   *  \param user_sender The invitation initiator
   *  \param user_target The user to invite
   */
  void Invite(UserID user_sender, UserID user_target);
  
private:
  void Send(UserID user, Message message);
  
  Users users_;
  ChatID id_;
  UserManager* user_manager_;
  
  //Thread safety
  Mutex mutex;
};

#endif /* CHAT_H */
