/**
 *  \file server/Inbox.h
 *  \brief Declares the Inbox class for the server. 
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 16:09:10 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef INBOX_H
#define INBOX_H

#include "TypeDef.h"
#include "Thread.h"
#include "ServerSocket.h"
#include "UserManager.h"
#include "ChatManager.h"
#include "Packet.h"

/**
 *  \class Inbox
 *  \brief Inbox handles incoming packet from the client via the Socket. Makes
 *  the appropriate call based on the type of packet.
 */
class Inbox: public Thread{
public:
  /**
   *  \brief Constructor
   *  \param socket The socket the inbox listens to.
   *  \param outbox The outbox that writes to the socket.
   *  \param user_manager The server user manager that handles login/logout 
   *  requests.
   *  \param chat_manager The server chat manager that handles chat related 
   *  requests
   */
  Inbox(ServerSocket* socket, Outbox* outbox, UserManager* user_manager, 
        ChatManager* chat_manager);
  
  /**
   *  /brief Destructor
   */
  virtual ~Inbox(){};
  
  /**
   *  \brief Contains the tasks for the thread to execute. 
   */
  virtual void Run();
    
private:
  //Attributes
  ServerSocket* socket_;
  Outbox* outbox_;
  UserManager* user_manager_;
  ChatManager* chat_manager_;
};

#endif /* INBOX_H */
