/**
 *  \file Observer.h
 *  \brief Declaration of an Observer class that implements the GOF Observer
 *  Design Pattern.
 *
 *  $LastChangedBy: jch231 $
 *  $Date: 2010-08-19 11:35:17 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef OBSERVER_H
#define OBSERVER_H

//Forward class declaration reduces the cyclic dependancy between
//Observer and Observable to a name-only dependancy.
class Observable;

/**
 *  \class Observer
 *  \brief Encapsulates the Observer class of the GOF Observer Design Pattern.
 *  
 *  Registers with an Observable object and is updated when any changes occur.
 */
class Observer {
public:
  /**
   *  \brief Constructor
   */
  Observer(){}
  
  /**
   *  \brief Destructor
   */
  virtual ~Observer(){}
  
  /**
   *  \brief Update the observer object. Called by the Observable subject. 
   *  \param subject A reference to the Observable subject that has called 
   *  update on this Observer.
   *
   *  The Observable subject passes a reference to itself in order to identify
   *  itself if the Observer->Observable relationship is one->many, or many->many.
   */
  virtual void Update(Observable* subject) = 0;
};

#endif /* OBSERVER_H */
