/**
 *  \file server/Outbox.cpp
 *  \brief Implements the Outbox class for the server
 *
 *  $LastChangedBy: sjk114 $
 *  $Date: 2010-08-19 16:09:10 +1200 (Thu, 19 Aug 2010) $
 *
 */

#include "Outbox.h"

Outbox::Outbox(ServerSocket* connection) {
  connection_ = connection;
  user_ = "";
}

void Outbox::LoginFailed() {
  Packet* packet = new Packet(LOGINFAILED);
  connection_->Send(packet);
}

void Outbox::LoginSuccess(UserID user) {
  user_ = user;
  Packet* packet = new Packet(LOGINSUCCESS);
  packet->target(user);
  connection_->Send(packet);
}  

void Outbox::AddUser(UserID user) {
  Packet* packet = new Packet(ADDUSER);
  packet->target(user);
  connection_->Send(packet);
} 

void Outbox::RemoveUser(UserID user) {
  Packet* packet = new Packet(REMOVEUSER);
  packet->target(user);
  connection_->Send(packet);
}

void Outbox::StartChat(ChatID id) {
  Packet* packet = new Packet(STARTCHAT);
  packet->chat(id);
  connection_->Send(packet);
} 

void Outbox::Send(Message message, ChatID chat) {
  Packet* packet = new Packet(SEND);
  packet->chat(chat);
  packet->message(message);
  connection_->Send(packet);
} 

UserID Outbox::LoggedIn() {
  return user_;
}



