/**
 *  \file Thread.h
 *  \brief Declaration of a Thread class that encapsulates a posix thread.
 *
 *  $LastChangedBy: jch231 $
 *  $Date: 2010-08-19 11:35:17 +1200 (Thu, 19 Aug 2010) $
 *
 */

#ifndef THREAD_H
#define THREAD_H

#include "pthread.h"
#include "stdio.h"

/**
 *  \class Thread
 *  \brief Encapsulates a posix thread. Can be inherited to make an object able
 *  to be threaded.
 */
class Thread {
public:
  /**
   *  /brief Constructor. Does not start the new thread. Call Thread::Start()
   *  to create the new thread which executes Thread::Run();
   */
  Thread(){}

  /**
   *  /brief Destructor
   */
  virtual ~Thread();
  
  /**
   *  \brief Start the thread. The new thread executes Thread::Run()
   */
  void Start();
  
  /**
   *  \brief Run the thread. Contains any tasks the thread is to carry out. May
   *  contain a loop that is only broken when Thread::Wait() is called.
   */
  virtual void Run() = 0;
  
  /**
   *  \brief Wait for the thread to finish.
   *  \return True if the thread was joined, false if not or the thread was not 
   *  started.
   */
  bool Wait();
  
protected: 
  //Thread joining flag.
  bool waiting;
  
private:
  //Attributes
  pthread_t thread_id;
  bool started;
};
  
#endif /* THREAD_H */
